@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -30,9 +30,9 @@
 
 #include "SDL_pspmouse_c.h"
 
-
 /* The implementation dependent data for the window manager cursor */
-struct WMcursor {
+struct WMcursor
+{
     int unused;
 };
 
