@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -22,8 +22,8 @@
 typedef struct
 {
     const char *tag;
-    void *(*CreateNativeWindow) (int w, int h);
-    void (*DestroyNativeWindow) (void *window);
+    void *(*CreateNativeWindow)(int w, int h);
+    void (*DestroyNativeWindow)(void *window);
 } NativeWindowFactory;
 
 #ifdef SDL_VIDEO_DRIVER_WINDOWS
@@ -44,3 +44,8 @@ extern NativeWindowFactory X11WindowFactory;
 #define TEST_NATIVE_COCOA
 extern NativeWindowFactory CocoaWindowFactory;
 #endif
+
+#ifdef SDL_VIDEO_DRIVER_OS2
+#define TEST_NATIVE_OS2
+extern NativeWindowFactory OS2WindowFactory;
+#endif
